%global pkgname sonata

Name:           gap-pkg-%{pkgname}
Version:        2.8
Release:        4%{?dist}
Summary:        GAP package for systems of nearrings

License:        GPLv2+
URL:            http://www.algebra.uni-linz.ac.at/Sonata/
Source0:        http://www.algebra.uni-linz.ac.at/Sonata/%{pkgname}-%{version}/%{pkgname}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  gap-devel
BuildRequires:  parallel
BuildRequires:  procps
BuildRequires:  tth

Requires:       gap-core

Suggests:       xgap

%description
SONATA stands for "systems of nearrings and their applications".  It
provides methods for the construction and the analysis of finite
nearrings.  A left nearring is an algebra (N;+,*), where (N,+) is a (not
necessarily abelian) group, (N,*) is a semigroup, and x*(y+z) = x*y + x*z
holds for all x,y,z in N.

As a typical example of a nearring, we may consider the set of all
mappings from a group G into G, where the addition is the pointwise
addition of mappings in G, and the multiplication is composition of
functions.  If functions are written on the right of their arguments,
then the left distributive law holds, while the right distributive law
is not satisfied for non-trivial G.

The SONATA package provides methods for the construction and analysis of
finite nearrings.
1. Methods for constructing all endomorphisms and all fixed-point-free
   automorphisms of a given group.
2. Methods for constructing the following nearrings of functions on a
   group G:
   - the nearring of polynomial functions of G (in the sense of
     Lausch-Nöbauer);
   - the nearring of compatible functions of G;
   - distributively generated nearrings such as I(G), A(G), E(G);
   - centralizer nearrings.
3. A library of all small nearrings (up to order 15) and all small
   nearrings with identity (up to order 31).
4. Functions to obtain solvable fixed-point-free automorphism groups on
   abelian groups, nearfields, planar nearrings, as well as designs from
   those.
5. Various functions to study the structure (size, ideals, N-groups, ...)
   of nearrings, to determine properties of nearring elements, and to
   decide whether two nearrings are isomorphic.
6. If the package XGAP is installed, the lattices of one- and two-sided
   ideals of a nearring can be studied interactively using a graphical
   representation.

%prep
%setup -q -n %{pkgname}

# Fix file encodings
for f in PackageInfo.g README.sonata; do
  iconv -f iso8859-1 -t utf-8 -o ${f}.utf8 $f
  touch -r $f ${f}.utf8
  mv -f ${f}.utf8 $f
done

# Delete KDE Desktop files
find . -name .directory | xargs rm -f

# Delete documentation log files
find . -name \*.log | xargs rm -f

# Use the main gap package's support files
rm -f doc/{convert.pl,gapmacro.tex}
ln -s %{_gap_dir}/etc/convert.pl doc/convert.pl
ln -s %{_gap_dir}/doc/gapmacro.tex doc/gapmacro.tex
ln -s %{_gap_dir}/doc/manualindex doc/manualindex

# Fix the documentation build script
sed -i 's,manual\\,manual;\\,g' doc/make_doc

%build
# Compress large data files
parallel %{?_smp_mflags} --no-notice gzip --best ::: nr/*.nr nri/*.nr

# Build the documentation
pushd doc
./make_doc
popd

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname} %{buildroot}%{_gap_dir}/pkg
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/README.sonata
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/{convert.pl,gapmacro.tex,make_doc,manualindex}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*/*.{aux,bbl,blg,idx,ilg,ind,log,toc}

%check
cd tst
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" << EOF
LoadPackage("sonata");
Test("fpf.tst", rec( compareFunction := "uptowhitespace" ));
Test("ideals.tst", rec( compareFunction := "uptowhitespace" ));
Test("nr.tst", rec( compareFunction := "uptowhitespace" ));
Test("tfms.tst", rec( compareFunction := "uptowhitespace" ));
EOF

%files
%doc README.sonata
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%license gpl-2.0.txt
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Thu Apr  7 2016 Jerry James <loganjerry@gmail.com> - 2.8-4
- Rebuild for gap 4.8.3

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 11 2015 Jerry James <loganjerry@gmail.com> - 2.8-2
- Drop scriptlets; gap-core now uses rpm file triggers
- Rebuild documentation from source
- Compress files in parallel

* Thu Oct  8 2015 Jerry James <loganjerry@gmail.com> - 2.8-1
- New upstream version

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jan 16 2015 Jerry James <loganjerry@gmail.com> - 2.6-4
- Initial RPM
